@@ -50,7 +50,7 @@ def clean_dataframe(df):
     dropped_rows = []
     for idx in df.index:
         local_time_str = df["LOG_TIME"][idx]
-        if (local_time_str == "-1") or len(local_time_str.split(' ')) > 3 or len(
+        if (local_time_str == "-1") or ("-1 " in local_time_str) or len(local_time_str.split(' ')) > 3 or len(
                 local_time_str.split('-')[0]) > 4 or len(local_time_str.split(' ')) < 2:
             dropped_rows.append(idx)
     df = df.drop(dropped_rows)
